==> v0.88.tar.gz: publik-base-theme/templates/variants/nancy-2017/prepare-template.py <==
#! /usr/bin/env python

import os
import subprocess
import re
import sys

FILENAME = 'tmp.html'

if os.path.exists(FILENAME):
    os.unlink(FILENAME)

URL = 'https://perso.entrouvert.org/~fred/nancy-2017/skeleton.html'
subprocess.call(['wget', '--quiet', '-O', FILENAME, '--convert-links', URL])
content = '{% load i18n static combo %}' + open(FILENAME).read().strip()
if len(content) < 500:
    sys.exit(0)

# remove tmp.html that have been added to anchor links
content = content.replace('tmp.html#', '#')

content = content.replace('@@TITLE@@',
        '{% firstof global_title "Nancy" %} {% block title %}{% endblock %}')

content = content.replace('<!-- @@HEAD@@ -->',
        '''
    {% block extra_top_head %}
    {% endblock %}
    {{ media }}
    <link rel="stylesheet" type="text/css" href="{{site_base}}{% static 'nancy-2017/style.css' %}?{{statics_hash}}">
    {% block extra_css %}
    {% endblock %}
    {% block extra_scripts %}
    {% endblock %}
    ''')

# arrange top links
content = content.replace('https://perso.entrouvert.org/"', '{{site_base}}/"')

toplinks = [
    ('Nancy en direct', '/nancy-en-direct/'),
    ('Centre de ressources', '/associations/'),
    ('Accueil Commerce', '/commerce-et-entreprise/')
]

for label, url in toplinks:
    content = content.replace('href="#" class="tooltip" data-tooltip="%s' % label,
            'href="{{site_base}}%s" class="tooltip" data-tooltip="%s' % (url, label))

content = re.sub('<body(.*?)>',
        r'<body {% block bodyargs %}{% endblock %}>',
        content)

content = content.replace('@@CONTENT@@',
        '''
<div class="gru-content" id="content">
{% block messages %}
{% if messages %}
  <div id="messages">
    <ul class="messages">
        {% for message in messages %}
        <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>
        {% endfor %}
    </ul>
  </div>
{% endif %}
{% endblock %}

            {% block content %}
            {% endblock %}
''')

# remove copy of jquery
content = re.sub('<script src=.*jquery.*min.js.*', '', content)

# remove scripts from end of page
content = re.sub(r'<script>.*/script>', '', content, flags=re.DOTALL)

# remove stratis footer line
content = re.sub(r'.*<p class="stratis">.*', '', content)

content = content.replace('@@TOPLINKS@@', '{% block user-info %}{% endblock %}')

open('theme.html', 'w').write(content)

==> v0.91.tar.gz: publik-base-theme/templates/variants/nancy-2017/prepare-template.py <==
#! /usr/bin/env python

import os
import subprocess
import re
import sys

FILENAME = 'tmp.html'

if os.path.exists(FILENAME):
    os.unlink(FILENAME)

URL = 'https://services.nancy.fr/static/_s/skeleton.html'
subprocess.call(['wget', '--quiet', '-O', FILENAME, '--convert-links', URL])
content = '{% load i18n static combo %}' + open(FILENAME).read().strip()
if len(content) < 500:
    sys.exit(0)

# remove tmp.html that have been added to anchor links
content = content.replace('tmp.html#', '#')

content = content.replace('@@TITLE@@',
        '{% firstof global_title "Nancy" %} {% block title %}{% endblock %}')

content = content.replace('<!-- @@HEAD@@ -->',
        '''
    {% block extra_top_head %}
    {% endblock %}
    {{ media }}
    <link rel="stylesheet" type="text/css" href="{{site_base}}{% static 'nancy-2017/style.css' %}?{{statics_hash}}">
    {% block extra_css %}
    {% endblock %}
    {% block extra_scripts %}
    {% endblock %}
    ''')

# arrange top links
content = content.replace('https://services.nancy.fr/"', '{{site_base}}/"')

toplinks = [
    ('Nancy en direct', '/nancy-en-direct/'),
    ('Centre de ressources', '/associations/'),
    ('Accueil Commerce', '/commerce-et-entreprise/')
]

for label, url in toplinks:
    content = content.replace('href="#" class="tooltip" data-tooltip="%s' % label,
            'href="{{site_base}}%s" class="tooltip" data-tooltip="%s' % (url, label))

content = re.sub('<body(.*?)>',
        r'<body {% block bodyargs %}{% endblock %}>',
        content)

content = content.replace('@@CONTENT@@',
        '''
<div class="gru-content" id="content">
{% block messages %}
{% if messages %}
  <div id="messages">
    <ul class="messages">
        {% for message in messages %}
        <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>
        {% endfor %}
    </ul>
  </div>
{% endif %}
{% endblock %}

            {% block content %}
            {% endblock %}
''')

# remove copy of jquery
content = re.sub('<script src=.*jquery.*min.js.*', '', content)

# remove scripts from end of page
content = re.sub(r'<script>.*/script>', '', content, flags=re.DOTALL)

# remove stratis footer line
content = re.sub(r'.*<p class="stratis">.*', '', content)

content = content.replace('@@TOPLINKS@@', '{% block user-info %}{% endblock %}')

open('theme.html', 'w').write(content)
